@@ -9,13 +9,16 @@ use crate::{
     systems::{
         borders::TailwindBorderStyle,
         filters::TailwindBrightness,
-        flexbox::{TailWindFlexGrow, TailWindFlexShrink, TailWindOrder, TailwindFlex, TailwindFlexDirection, TailwindFlexWrap},
+        flexbox::{TailWindGrow, TailWindOrder, TailWindShrink, TailwindFlex, TailwindFlexDirection, TailwindFlexWrap},
     },
-    TailwindBorderCollapse, TailwindBoxDecorationBreak, TailwindBoxSizing, TailwindClear, TailwindColumns, TailwindContainer,
-    TailwindDisplay, TailwindDivideStyle, TailwindFloat, TailwindFontFamily, TailwindFontSize, TailwindFontSmoothing,
-    TailwindFontStyle, TailwindFontWeight, TailwindIsolation, TailwindLeading, TailwindOutlineStyle, TailwindPosition,
-    TailwindRingOffsetWidth, TailwindScreenReader, TailwindShadow, TailwindSizing, TailwindSpacing, TailwindTextAlignment,
-    TailwindTextColor, TailwindTracking, TailwindUnderlineOffset, TailwindVisibility,
+    TailwindBorderCollapse, TailwindBoxDecorationBreak, TailwindBoxSizing, TailwindBreak, TailwindClear, TailwindColumns,
+    TailwindContainer, TailwindContent, TailwindDisplay, TailwindDivideStyle, TailwindFloat, TailwindFontFamily,
+    TailwindFontSize, TailwindFontSmoothing, TailwindFontStyle, TailwindFontVariantNumeric, TailwindFontWeight,
+    TailwindIsolation, TailwindLayoutBreak, TailwindLeading, TailwindListStyle, TailwindListStylePosition, TailwindObjectFit,
+    TailwindObjectPosition, TailwindOutlineStyle, TailwindOverflow, TailwindOverscroll, TailwindPosition,
+    TailwindRingOffsetWidth, TailwindRotate, TailwindScale, TailwindScreenReader, TailwindShadow, TailwindSizing, TailwindSkew,
+    TailwindSpacing, TailwindTextAlignment, TailwindTextColor, TailwindTextDecoration, TailwindTextOverflow,
+    TailwindTextTransform, TailwindTracking, TailwindUnderlineOffset, TailwindVisibility,
 };
 use log::error;
 use std::{
@@ -112,23 +115,30 @@ impl AstStyle {
         let element = self.view_elements();
         let arbitrary = self.view_arbitrary();
         let instance = match element.as_slice() {
-            // ["w", rest @ ..] => {TailW}
             // Layout System
             ["aspect", rest @ ..] => TailwindAspect::parse(rest, arbitrary)?.boxed(),
             ["container"] => TailwindContainer {}.boxed(),
             ["columns", rest @ ..] => TailwindColumns::parse(rest)?.boxed(),
-            ["break", "before", rest @ ..] => TailwindBreak::parse_before(rest)?.boxed(),
-            ["break", "inside", rest @ ..] => TailwindBreak::parse_inside(rest)?.boxed(),
-            ["break", "after", rest @ ..] => TailwindBreak::parse_after(rest)?.boxed(),
+            ["break", rest @ ..] => Self::break_adaptor(rest, arbitrary)?,
             ["box", rest @ ..] => Self::box_adaptor(rest, arbitrary)?,
-            ["block"] => TailwindDisplay::Block.boxed(),
             // begin https://tailwindcss.com/docs/display
-            ["inline", "flex"] => TailwindDisplay::InlineFlex.boxed(),
+            ["block"] => TailwindDisplay::Block.boxed(),
             ["inline", "block"] => TailwindDisplay::InlineBlock.boxed(),
-            // end https://tailwindcss.com/docs/display
+            ["inline"] => TailwindDisplay::InlineFlex.boxed(),
+            // flex catched
+            ["inline", "flex"] => TailwindDisplay::InlineFlex.boxed(),
+            // table catched
+            ["inline", "table"] => TailwindDisplay::InlineFlex.boxed(),
+            // table catched
+            ["flow", "root"] => TailwindDisplay::InlineFlex.boxed(),
+            // grid catched
+            ["inline", "grid"] => TailwindDisplay::InlineFlex.boxed(),
+            ["contents"] => TailwindDisplay::InlineFlex.boxed(),
+            // list catched
+            ["hidden"] => TailwindDisplay::InlineFlex.boxed(),
+            // https://tailwindcss.com/docs/float
             ["float", rest @ ..] => Self::float_adaptor(rest, arbitrary)?,
             ["clear", rest @ ..] => TailwindClear::parse(rest)?.boxed(),
-
             ["isolate"] => TailwindIsolation::Isolate.boxed(),
             ["isolation", "auto"] => TailwindIsolation::Auto.boxed(),
             ["object", rest @ ..] => Self::object_adaptor(rest, arbitrary)?,
@@ -140,19 +150,34 @@ impl AstStyle {
             ["absolute"] => TailwindPosition::Absolute.boxed(),
             ["relative"] => TailwindPosition::Relative.boxed(),
             ["sticky"] => TailwindPosition::Sticky.boxed(),
-            // end https://tailwindcss.com/docs/position
+            // https://tailwindcss.com/docs/top-right-bottom-left
+            ["inset", rest @ ..] => TailWindZIndex::parse(rest, self.negative),
+            ["top", rest @ ..] => TailWindZIndex::parse(rest, self.negative),
+            ["right", rest @ ..] => TailWindZIndex::parse(rest, self.negative),
+            ["buttom", rest @ ..] => TailWindZIndex::parse(rest, self.negative),
+            ["left", rest @ ..] => TailWindZIndex::parse(rest, self.negative),
+            // https://tailwindcss.com/docs/visibility
             ["visible"] => TailwindVisibility::Visible.boxed(),
             ["invisible"] => TailwindVisibility::Invisible.boxed(),
-
-            ["inset", rest @ ..] => TailWindZIndex::parse(rest, self.negative),
-
-            ["s", rest @ ..] => TailWindZIndex::parse(rest, self.negative),
+            // https://tailwindcss.com/docs/z-index
+            ["z", rest @ ..] => TailWindZIndex::parse(rest, self.negative),
             // Flexbox & Grid
+            ["basis", rest @ ..] => todo!(),
             ["flex", rest @ ..] => Self::flex_adaptor(rest, arbitrary)?,
-            ["grow", rest @ ..] => TailWindFlexGrow::parse(rest, arbitrary)?.boxed(),
-            ["shrink", rest @ ..] => TailWindFlexShrink::parse(rest, arbitrary)?.boxed(),
+            ["grow", rest @ ..] => TailWindGrow::parse(rest, arbitrary)?.boxed(),
+            ["shrink", rest @ ..] => TailWindShrink::parse(rest, arbitrary)?.boxed(),
             ["order", rest @ ..] => TailWindOrder::parse(rest, arbitrary, self.negative)?.boxed(),
-
+            ["grid", rest @ ..] => Self::grid_adaptor(rest, arbitrary)?,
+            // https://tailwindcss.com/docs/grid-column
+            ["col", rest @ ..] => todo!(),
+            ["row", rest @ ..] => todo!(),
+            ["auto", rest @ ..] => todo!(),
+            ["gap", rest @ ..] => todo!(),
+            ["justify", rest @ ..] => Self::justify_adaptor(rest, arbitrary)?,
+            ["content", rest @ ..] => todo!(),
+            ["items", rest @ ..] => todo!(),
+            ["self", rest @ ..] => todo!(),
+            ["justify", rest @ ..] => Self::place_adaptor(rest, arbitrary)?,
             // Spacing System
             [p @ ("p" | "pl" | "pr" | "pm" | "pt" | "px" | "py"), rest @ ..] => {
                 TailwindSpacing::parse_padding(rest, p, arbitrary)?.boxed()
@@ -171,22 +196,46 @@ impl AstStyle {
             ["max", "h", rest @ ..] => TailwindSizing::parse_width_max(rest, arbitrary)?.boxed(),
             // Typography System
             ["font", rest @ ..] => Self::font_adaptor(rest, arbitrary)?,
-            // begin https://tailwindcss.com/docs/font-variant-numeric
-            ["normal", "nums"] => todo!(),
-            ["ordinal"] => todo!(),
-            // end https://tailwindcss.com/docs/font-variant-numeric
             ["text", rest @ ..] => Self::text_adaptor(rest, arbitrary)?,
+            // begin https://tailwindcss.com/docs/font-variant-numeric
             ["antialiased"] => TailwindFontSmoothing::new(false).boxed(),
             ["subpixel", "antialiased"] => TailwindFontSmoothing::new(true).boxed(),
             ["italic"] => TailwindFontStyle::Italic.boxed(),
             ["not", "italic"] => TailwindFontStyle::Normal.boxed(),
-            // TODO: https://tailwindcss.com/docs/font-variant-numeric
+            // https://tailwindcss.com/docs/font-variant-numeric
+            ["normal", "nums"] => TailwindFontVariantNumeric::Normal.boxed(),
+            ["ordinal"] => TailwindFontVariantNumeric::Ordinal.boxed(),
+            ["slashed", "zero"] => TailwindFontVariantNumeric::SlashedZero.boxed(),
+            ["lining", "nums"] => TailwindFontVariantNumeric::Lining.boxed(),
+            ["oldstyle", "nums"] => TailwindFontVariantNumeric::OldStyle.boxed(),
+            ["proportional", "nums"] => TailwindFontVariantNumeric::Proportional.boxed(),
+            ["tabular", "nums"] => TailwindFontVariantNumeric::Tabular.boxed(),
+            ["diagonal", "fractions"] => TailwindFontVariantNumeric::DiagonalFractions.boxed(),
+            ["stacked", "fractions"] => TailwindFontVariantNumeric::StackedFractions.boxed(),
+            // https://tailwindcss.com/docs/letter-spacing
             ["tracking", rest @ ..] => TailwindTracking::parse(rest, arbitrary)?.boxed(),
             ["leading", rest @ ..] => TailwindLeading::parse(rest, arbitrary)?.boxed(),
             ["list", rest @ ..] => Self::list_adaptor(rest, arbitrary)?,
-            // TODO:https://tailwindcss.com/docs/font-variant-numeric
+            // https://tailwindcss.com/docs/text-decoration
+            ["underline"] => TailwindTextDecoration::Underline.boxed(),
+            ["overline"] => TailwindTextDecoration::Overline.boxed(),
+            ["line", "through"] => TailwindTextDecoration::ThroughLine.boxed(),
+            ["no", "underline"] => TailwindTextDecoration::None.boxed(),
+            // https://tailwindcss.com/docs/text-decoration-color
+            ["decoration", rest @ ..] => Self::decoration_adaptor(rest, arbitrary)?,
             ["underline", "offset", rest @ ..] => TailwindUnderlineOffset::parse(rest, arbitrary)?.boxed(),
-            ["decoration", rest @ ..] => todo!(),
+            // https://tailwindcss.com/docs/text-transform
+            ["uppercase"] => TailwindTextTransform::Uppercase.boxed(),
+            ["lowercase"] => TailwindTextTransform::Lowercase.boxed(),
+            ["capitalize"] => TailwindTextTransform::Capitalize.boxed(),
+            ["normal", "case"] => TailwindTextTransform::None.boxed(),
+            // https://tailwindcss.com/docs/text-overflow
+            ["truncate"] => TailwindTextOverflow::Truncate.boxed(),
+            ["indent", rest @ ..] => todo!(),
+            ["align", rest @ ..] => todo!(),
+            ["whitespace", rest @ ..] => todo!(),
+            ["break", rest @ ..] => todo!(),
+            ["content", "none"] => TailwindContent::None.boxed(),
             // Typography System Extension
             ["prose"] => todo!(),
             // Backgrounds System
@@ -209,11 +258,13 @@ impl AstStyle {
             ["blur", rest @ ..] => todo!(),
             ["brightness", rest @ ..] => TailwindBrightness::parse(rest, arbitrary)?.boxed(),
             ["contrast", rest @ ..] => todo!(),
-
             ["drop", "shadow", rest @ ..] => TailwindShadow::parse_drop(rest, arbitrary)?.boxed(),
-
             ["grayscale", rest @ ..] => todo!(),
-            ["backdrop", rest @ ..] => todo!(),
+            ["hue", "rotate", rest @ ..] => todo!(),
+            ["invert", rest @ ..] => todo!(),
+            ["saturate", rest @ ..] => todo!(),
+            ["sepia", rest @ ..] => todo!(),
+            ["backdrop", rest @ ..] => Self::backdrop_adaptor(rest, arbitrary)?,
             // Tables System
             ["table", rest @ ..] => Self::table_adaptor(rest, arbitrary)?,
             // Transitions System
@@ -222,23 +273,32 @@ impl AstStyle {
             ["ease", rest @ ..] => todo!(),
             ["delay", rest @ ..] => todo!(),
             ["animate", rest @ ..] => todo!(),
-            ["ease", rest @ ..] => todo!(),
-            ["delay", rest @ ..] => todo!(),
             // Transforms System
-            ["scale", "x", rest @ ..] => todo!(),
-            ["scale", "y", rest @ ..] => todo!(),
-            ["scale", rest @ ..] => todo!(),
-            ["rotate", rest @ ..] => todo!(),
-            ["translate", rest @ ..] => todo!(),
-            ["rotate", rest @ ..] => todo!(),
-            ["skew", "x", rest @ ..] => todo!(),
-            ["skew", "y", rest @ ..] => todo!(),
+            ["scale", "x", rest @ ..] => TailwindScale::parse(rest, arbitrary, Some(true))?.boxed(),
+            ["scale", "y", rest @ ..] => TailwindScale::parse(rest, arbitrary, Some(false))?.boxed(),
+            ["scale", rest @ ..] => TailwindScale::parse(rest, arbitrary, None)?.boxed(),
+            ["rotate", rest @ ..] => TailwindRotate::parse(rest, arbitrary)?.boxed(),
+            ["translate", "x", rest @ ..] => todo!(),
+            ["translate", "y", rest @ ..] => todo!(),
+            ["skew", "x", rest @ ..] => TailwindSkew::parse(rest, arbitrary, true)?.boxed(),
+            ["skew", "y", rest @ ..] => TailwindSkew::parse(rest, arbitrary, false)?.boxed(),
             ["origin", rest @ ..] => todo!(),
             // Interactivity System
             ["accent", rest @ ..] => todo!(),
-
+            // https://tailwindcss.com/docs/appearance
+            ["appearance", "none"] => todo!(),
+            ["cursor", rest @ ..] => todo!(),
+            ["caret", rest @ ..] => todo!(),
+            ["pointer", "events", rest @ ..] => todo!(),
+            ["resize", rest @ ..] => todo!(),
+            ["scroll", rest @ ..] => todo!(),
+            ["snap", rest @ ..] => todo!(),
+            ["touch", rest @ ..] => todo!(),
+            ["select", rest @ ..] => todo!(),
+            ["will", "change", rest @ ..] => todo!(),
             // SVG System
-            ["svg", rest @ ..] => todo!(),
+            ["fill", rest @ ..] => todo!(),
+            ["stroke", rest @ ..] => todo!(),
             // Accessibility System
             ["sr", "only"] => TailwindScreenReader::new(true).boxed(),
             ["not", "sr", "only"] => TailwindScreenReader::new(false).boxed(),
@@ -247,7 +307,23 @@ impl AstStyle {
         };
         Ok(instance)
     }
-
+    #[inline]
+    fn break_adaptor(str: &[&str], _: &str) -> Result<Box<dyn TailwindInstance>> {
+        let out = match str {
+            // https://tailwindcss.com/docs/border-style
+            ["normal"] => TailwindBreak::Normal.boxed(),
+            ["words"] => TailwindBreak::Words.boxed(),
+            ["all"] => TailwindBreak::All.boxed(),
+            // https://tailwindcss.com/docs/break-before
+            ["before", rest @ ..] => TailwindLayoutBreak::parse_before(rest)?.boxed(),
+            // https://tailwindcss.com/docs/break-inside
+            ["inside", rest @ ..] => TailwindLayoutBreak::parse_inside(rest)?.boxed(),
+            // https://tailwindcss.com/docs/break-after
+            ["after", rest @ ..] => TailwindLayoutBreak::parse_after(rest)?.boxed(),
+            _ => return syntax_error!("Unknown break instructions: {}", str.join("-")),
+        };
+        Ok(out)
+    }
     #[inline]
     fn border_adaptor(str: &[&str]) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
@@ -368,22 +444,43 @@ impl AstStyle {
         };
         Ok(out)
     }
-
+    #[inline]
+    fn grid_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
+        todo!()
+    }
+    #[inline]
+    fn justify_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
+        todo!()
+    }
+    #[inline]
+    fn place_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
+        todo!()
+    }
     #[inline]
     fn list_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/list-style-type
-            ["none"] => todo!(),
-            ["disc"] => todo!(),
-            ["decimal"] => todo!(),
+            ["none"] => TailwindListStyle::None.boxed(),
+            ["disc"] => TailwindListStyle::Disc.boxed(),
+            ["decimal"] => TailwindListStyle::Decimal.boxed(),
             // https://tailwindcss.com/docs/list-style-position
-            ["inside"] => todo!(),
-            ["outside"] => todo!(),
+            ["inside"] => TailwindListStylePosition::Inside.boxed(),
+            ["outside"] => TailwindListStylePosition::Outside.boxed(),
+            // https://tailwindcss.com/docs/list-style-type#arbitrary-values
+            [] => TailwindListStyle::parse_arbitrary(arbitrary)?.boxed(),
             _ => return syntax_error!("Unknown list instructions: {}", str.join("-")),
         };
         Ok(out)
     }
     #[inline]
+    fn decoration_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
+        todo!()
+    }
+    #[inline]
+    fn backdrop_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
+        todo!()
+    }
+    #[inline]
     fn table_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/display#table
@@ -399,7 +496,7 @@ impl AstStyle {
         Ok(out)
     }
     #[inline]
-    fn float_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
+    fn float_adaptor(str: &[&str], _: &str) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/float
             ["left"] => TailwindFloat::Left.boxed(),
@@ -413,24 +510,44 @@ impl AstStyle {
     #[inline]
     fn object_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
-            // https://tailwindcss.com/docs/float
+            // https://tailwindcss.com/docs/object-fit
+            ["contain"] => TailwindObjectFit::Contain.boxed(),
+            ["cover"] => TailwindObjectFit::Cover.boxed(),
+            ["fill"] => TailwindObjectFit::Fill.boxed(),
+            ["none"] => TailwindObjectFit::None.boxed(),
+            ["scale", "down"] => TailwindObjectFit::ScaleDown.boxed(),
+            // https://tailwindcss.com/docs/object-position
+            ["7"] | ["left", "top"] => TailwindObjectPosition::LeftTop.boxed(),
+            ["8"] | ["top"] => TailwindObjectPosition::Bottom.boxed(),
+            ["9"] | ["right", "top"] => TailwindObjectPosition::Bottom.boxed(),
+            ["4"] | ["left"] => TailwindObjectPosition::Bottom.boxed(),
+            ["5"] | ["center"] => TailwindObjectPosition::Bottom.boxed(),
+            ["6"] | ["right"] => TailwindObjectPosition::Bottom.boxed(),
+            ["1"] | ["left", "buttom"] => TailwindObjectPosition::Bottom.boxed(),
+            ["2"] | ["buttom"] => TailwindObjectPosition::Bottom.boxed(),
+            ["3"] | ["right", "buttom"] => TailwindObjectPosition::Bottom.boxed(),
+            [] => TailwindObjectPosition::parse_arbitrary(arbitrary)?.boxed(),
             _ => return syntax_error!("Unknown object instructions: {}", str.join("-")),
         };
         Ok(out)
     }
     #[inline]
-    fn overflow_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
+    fn overflow_adaptor(str: &[&str], _: &str) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
-            // https://tailwindcss.com/docs/float
-            _ => return syntax_error!("Unknown overflow instructions: {}", str.join("-")),
+            // https://tailwindcss.com/docs/overflow
+            ["x", pattern @ ..] => TailwindOverflow::parse_x(pattern)?.boxed(),
+            ["y", pattern @ ..] => TailwindOverflow::parse_y(pattern)?.boxed(),
+            _ => TailwindOverflow::parse_xy(str)?.boxed(),
         };
         Ok(out)
     }
     #[inline]
-    fn overscroll_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
+    fn overscroll_adaptor(str: &[&str], _: &str) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
-            // https://tailwindcss.com/docs/float
-            _ => return syntax_error!("Unknown overscroll instructions: {}", str.join("-")),
+            // https://tailwindcss.com/docs/overscroll-behavior
+            ["x", pattern @ ..] => TailwindOverscroll::parse_x(pattern)?.boxed(),
+            ["y", pattern @ ..] => TailwindOverscroll::parse_y(pattern)?.boxed(),
+            _ => TailwindOverscroll::parse_xy(str)?.boxed(),
         };
         Ok(out)
     }
