@@ -3,6 +3,6 @@ macro_rules! css_attributes {
     // map-like
     ($($k:expr => $v:expr),* $(,)?) => {{
         use std::iter::{Iterator, IntoIterator};
-        Iterator::collect(IntoIterator::into_iter([$(CssAttribute::new($k, $v),)*]))
+        Iterator::collect(IntoIterator::into_iter([$(CssAttribute::new($k.to_string(), $v.to_string()),)*]))
     }};
 }
